@@ -48,13 +48,25 @@ class EventsManager extends CGExtensions
 			$name = $this->Lang('friendlyname');
 		return $name;
 	}
-	function GetVersion() { return '0.2.2'; }
-	function GetHelp() { return $this->Lang('help'); }
+	function GetVersion() { return '1.2.3'; }
+	function GetHelp() {
+		$main_help = $this->Lang('help');
+		$examples_help = $this->Lang('help_examples');
+
+		$tabs_top = $this->StartTabHeaders();
+		$tabs_top .= $this->SetTabHeader('main_help', $this->Lang('main_help_tab'));
+		$tabs_top .= $this->SetTabHeader('examples_help', $this->Lang('examples_help_tab'));
+		$tabs_top .= $this->EndTabHeaders();
+
+		$total_help = $tabs_top;
+		$total_help .= $this->StartTabContent() . $this->StartTab('main_help') . $main_help . $this->EndTab() . $this->StartTab('examples_help') . $examples_help . $this->EndTab() . $this->EndTabContent();
+		return $total_help;
+	}
 	function GetAuthor() { return 'AireLibre'; }
 	function GetAuthorEmail() { return 'contact@airelibre.fr'; }
 	function GetChangeLog() { return file_get_contents(__FILE__).'/doc/changelog.html'; }
 	function MinimumCMSVersion() {return '1.10';}
-	function MaximumCMSVersion() {return '1.11';}
+	//function MaximumCMSVersion() {return '1.11';}
 	
 	function InstallPostMessage() { return $this->Lang('postinstall'); }
 	function UninstallPreMessage() {return $this->Lang('preuninstall'); }
@@ -64,11 +76,14 @@ class EventsManager extends CGExtensions
 	function HasAdmin() { return true; }
 	function GetAdminSection() { return 'content'; }
 	function GetAdminDescription () { return $this->Lang('admindescription'); }
+
+	function GetEventDescription($eventname) { return $this->lang('eventdesc_'.$eventname);}
+	function GetEventHelp($eventname) { return $this->lang('eventhelp_'.$eventname); }
 	
 	function VisibleToAdminUser() {return true;}
 	function GetDependencies()
 	{
-		return (array('CGExtensions'=>'1.24', 'FrontEndUsers'=>'1.16'));
+		return (array('AireLibs'=>'1.3', 'CGExtensions'=>'1.24', 'FrontEndUsers'=>'1.16'));
 	}
 	
 	// Non API function - Defined to handle the rights easier (with a default value)
@@ -117,6 +132,7 @@ class EventsManager extends CGExtensions
 		$this->SetParameterType('myevents', CLEAN_STRING);
 		$this->SetParameterType('sortby', CLEAN_STRING);
 		$this->SetParameterType('sortorder', CLEAN_STRING);
+		$this->SetParameterType('allow_notconnected', CLEAN_INT);
 		
 		// Templates
 		$this->SetParameterType('summarytemplate', CLEAN_STRING);
@@ -133,12 +149,13 @@ class EventsManager extends CGExtensions
 		$this->CreateParameter('category_id', '0', $this->Lang('param_category_id'));
 		$this->CreateParameter('category', '', $this->Lang('param_category'));
 		$this->CreateParameter('status', 'published', $this->Lang('param_status'));
-		$this->CreateParameter('show', 'upcoming', $this->Lang('param_show'));
+		$this->CreateParameter('show', 'all', $this->Lang('param_show'));
 		$this->CreateParameter('start_datetime', '', $this->Lang('param_start_datetime'));
 		$this->CreateParameter('end_datetime', '', $this->Lang('param_end_datetime'));
 		$this->CreateParameter('myevents', 'false', $this->Lang('param_myevents'));
 		$this->CreateParameter('sortby', 'name', $this->Lang('param_sortby'));
 		$this->CreateParameter('sortorder', 'ASC', $this->Lang('param_sortorder'));
+		$this->CreateParameter('allow_notconnected', '0', $this->Lang('param_allow_notconnected'));
 		
 		// Templates
 		$this->CreateParameter('summarytemplate', '', $this->Lang('param_summarytemplate'));
