@@ -77,6 +77,8 @@ $events = EventsManager_events_ops::get_events($status, $category_id, $category_
 $events_smarty = array();
 if (count($events) != 0)
 {
+	$FieldsManager = new AireFieldsManager();
+	
 	$eventsurlprefix = $this->GetPrefix('events');
 	$registrationurlprefix = $this->GetPrefix('register');
 	
@@ -113,8 +115,13 @@ if (count($events) != 0)
 				$prettyurl .= '/d,' . $params['registrationtemplate'];
 			}
 			
-			$event_smarty->registration_url = $this->CreateFrontendLink($id, $registrationpage, 'registration', '', $sendtoregistration, '', 1, $inline, '', '', $prettyurl);
+			$event_smarty->registration_url = $this->CreateFrontendLink($id, $registrationpage, 'register', '', $sendtoregistration, '', 1, $inline, '', '', $prettyurl);
 		}
+
+		// Add custom fields
+		$event_smarty->fields = $FieldsManager->get_fieldsbyname('EventsManager', $event->id, '', '', '');
+
+		// Add the number of registered users
 		
 		$events_smarty[] = $event_smarty;
 	}
@@ -132,4 +139,6 @@ $template = $this->GetPreference('dflt_summary_template');
 if  (!empty($params['summarytemplate']))
 	$template = $params['summarytemplate'];
 echo $this->ProcessTemplateFromDatabase('summary_' . $template);
+// Test
+//echo $this->ProcessTemplate('orig_summarytemplate.tpl');
 ?>
\ No newline at end of file
