@@ -18,6 +18,17 @@ else
 	if ($detailpage == '-1')
 		$detailpage = $returnid;
 }
+
+// Registration page ID ?
+$registrationpage = '';
+if (isset($params['registrationpage']) and !empty($params['registrationpage']))
+	$registrationpage = $params['registrationpage'];
+else
+{
+	$registrationpage = $this->GetPreference('dflt_registrationpage', '-1');
+	if ($registrationpage == '-1')
+		$registrationpage = $returnid;
+}
 	
 // Manage the event
 $event = new EventsManager_event($params['event_id']);
@@ -31,11 +42,15 @@ if ($event->allow_registration)
 	$urlprefix = $this->GetPrefix('events');
 	$registrationurlprefix = $this->GetPrefix('register');
 
-	$prettyurl = $urlprefix.'/'.$registrationurlprefix.'/'.$event->id.'/'.$detailpage.'/'.$aliased_title;
+	$prettyurl = $urlprefix.'/'.$registrationurlprefix.'/'.$event->id.'/'.$registrationpage.'/'.$aliased_title;
 	
-	$event_smarty->registration_url = $this->CreateFrontendLink($id, $returnid, 'registration', '', array('event_id'=>$event->id), '', 1, $inline, '', '', $prettyurl);
+	$event_smarty->registration_url = $this->CreateFrontendLink($id, $registrationpage, 'register', '', array('event_id'=>$event->id), '', 1, $inline, '', '', $prettyurl);
 }
 
+// Add custom fields
+$FieldsManager = new AireFieldsManager();
+$event_smarty->fields = $FieldsManager->get_fieldsbyname('EventsManager', $event->id, '', '', '');
+
 /******************************************************************************
 // Display */
 
@@ -47,4 +62,5 @@ $template = $this->GetPreference('dflt_detail_template');
 if  (!empty($params['detailtemplate']))
 	$template = $params['detailtemplate'];
 echo $this->ProcessTemplateFromDatabase('detail_' . $template);
+//echo $this->ProcessTemplate('orig_detailtemplate.tpl');
 ?>
\ No newline at end of file
