@@ -1,6 +1,6 @@
 <?php
 
-class EventsManager_category extends EventsManager_object
+class EventsManager_category extends AireDbObject
 {
 	protected $table = 'events_categories';
 	
