@@ -30,5 +30,8 @@ $this->RemoveEvent('EventsManagerCategoryDeleted');
 $this->RemoveEvent('EventsManagerRegistrationAdded');
 $this->RemoveEvent('EventsManagerRegistrationEdited');
 
+// Events handlers
+$this->RemoveEventHandler('FrontEndUsers', 'OnLogin');
+
 
 ?>
\ No newline at end of file
